@@ -18,6 +18,7 @@ public:
     ~MainWindow();
 
     void start();
+    void setupCategories();
 
 
 private slots:
@@ -25,7 +26,7 @@ private slots:
     void itemActivated(QListWidgetItem*);
 
     void populate();
-
+    void changeCategory();
 
 protected:
     void changeEvent(QEvent *e);
