@@ -2,6 +2,7 @@
 #define PLATUTIL_H
 
 class QWidget;
+class QString;
 
 class PlatUtil
 {
@@ -9,6 +10,7 @@ public:
     PlatUtil();
     static void configureWindow(QWidget* wdg);
     static void toggleBusy(QWidget* wdg, bool busy);
+    static QString configFile();
 };
 
 #endif // PLATUTIL_H
